==> ThbgmExtractor-1.6.2.tar.bz2: ThbgmExtractor-1.6.2/gui/ThbgmExtractor/Smdn.Applications.ThbgmExtractor/ThbgmExtractor.cs <==
//  
//  Author:
//       smdn <smdn@smdn.jp>
// 
//  Copyright (c) 2004-2014 smdn
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Resources;
using System.Text;
using System.Windows.Forms;

using Smdn.Formats.Thbgm;
using Smdn.IO;
using Smdn.Windows.Forms.ThbgmPlayer;

namespace Smdn.Applications.ThbgmExtractor {
  public static class ThbgmExtractor {
    private static StringBuilder log = new StringBuilder(1024 * 1024);

    public static StringBuilder Log {
      get { return log; }
    }

    private static ResourceManager resourceManager = new ResourceManager("Smdn.Applications.ThbgmExtractor.Texts", typeof(ThbgmExtractor).Assembly);
    private static CultureInfo resourceCulture = null;

    public static System.Globalization.CultureInfo Culture {
      get { return resourceCulture; }
      set { resourceCulture = value; }
    }

    private static /*readonly*/ ReadOnlyCollection<ProductInfo> products;

    public static ReadOnlyCollection<ProductInfo> Products {
      get { return products; }
    }

    private static /*readonly*/ ReadOnlyCollection<EncoderConfig> encoderConfigs;

    public static ReadOnlyCollection<EncoderConfig> EncoderConfigs {
      get { return encoderConfigs; }
    }

    public static string VersionString {
      get { return string.Format("{0} {1}", Application.ProductName, Application.ProductVersion); }
    }

    private static string searchDirectory;

    [STAThread]
    public static void Main(string[] args)
    {
#if DEBUG
      resourceCulture = System.Globalization.CultureInfo.GetCultureInfo("en");
      Texts.Culture = resourceCulture;
      System.Threading.Thread.CurrentThread.CurrentUICulture = resourceCulture;
#endif

      var logWriter = TextWriter.Synchronized(new StringWriter(log));

#if false && DEBUG
      Console.SetError(logWriter);

      Console.WriteLine("current directory: {0}", Environment.CurrentDirectory);
      Console.WriteLine("executable directory: {0}", Path.GetDirectoryName(Application.ExecutablePath));
#else
      Console.SetOut(logWriter);
      Console.SetError(logWriter);
#endif

      searchDirectory = Path.GetDirectoryName(Application.ExecutablePath);

      ReloadProductInfoes();

      Config.Load(searchDirectory);

      ReloadEncoderConfig();

      Application.EnableVisualStyles();
      Application.DoEvents();

      using (var dialog = new MainDialog()) {
        if (0 < args.Length) {
          if (PathUtils.AreExtensionEqual(args[0], ExtractionConfig.FileExtension)) {
            dialog.LoadExtractionConfig(args[0], true);
          }
          else {
            var product = ProductInfo.FindMatchedProduct(args[0], products);

            if (product != null) {
              var config = new ExtractionConfig();

              config.Product = product;
              config.BgmSourcePath = product.InstalledBgmSourcePath;
              config.EncoderConfig = EncoderConfig.Empty;
              config.Tracks = product.Tracks.Select(delegate(TrackInfo trackInfo) {
                return new Track(trackInfo);
              }).ToList().AsReadOnly();

              dialog.ExtractOnShown(config);
            }
          }
        }
        Application.Run(dialog);
      }

      Config.Save(products);
    }

    internal static void ReloadProductInfoes()
    {
      lock (ProductInfo.EmbeddedProducts) {
        var productsAndDates = new Dictionary<ProductInfo, DateTime>();

        foreach (var product in ProductInfo.EmbeddedProducts) {
          productsAndDates[product] = product.ReleaseDate;
        }

        foreach (var pair in LoadProductInfo(searchDirectory)) {
          var date = pair.Value.ReleaseDate;

          if (date == DateTime.MinValue)
            // use last write time instead of ProductInfo.ReleaseDate
            date = File.GetLastWriteTime(pair.Key);

          productsAndDates[pair.Value] = date;
        }

        // order by date of product info
        products = productsAndDates.OrderByDescending(pair => pair.Value).Select(pair => pair.Key).ToList().AsReadOnly();

        // load user environment info
        Config.Load(searchDirectory, products);
      }
    }

    private static Dictionary<string, ProductInfo> LoadProductInfo(string searchDirectory)
    {
      var ret = new Dictionary<string, ProductInfo>();

      try {
        foreach (var file in ProductInfo.SearchProductInfoFiles(searchDirectory, SearchOption.TopDirectoryOnly)) {
          try {
            var product = ProductInfo.LoadFrom(file);

            Console.WriteLine("loaded: {0} ({1})", file, product.Title);

            ret.Add(file, product);
          }
          catch (Exception ex) {
            Console.Error.WriteLine("file: {0}{1}{2}", file, Environment.NewLine, ex);
          }
        }
      }
      catch (Exception ex) {
        Console.Error.WriteLine(ex);
      }

      return ret;
    }

    internal static void ReloadEncoderConfig()
    {
      try {
        encoderConfigs = EncoderConfig.LoadFrom(Path.Combine(searchDirectory, EncoderConfig.ConfigFileName));
      }
      catch (Exception ex) {
        encoderConfigs = Array.AsReadOnly(new[] {EncoderConfig.Empty});
        Console.Error.WriteLine(ex);
      }
    }

    public static string GetText(string name, params object[] args)
    {
      return string.Format(resourceManager.GetString(name, resourceCulture) ?? string.Empty, args);
    }
  }
}

==> ThbgmExtractor-1.6.4.tar.bz2: ThbgmExtractor-1.6.4/gui/ThbgmExtractor/Smdn.Applications.ThbgmExtractor/ThbgmExtractor.cs <==
//  
//  Author:
//       smdn <smdn@smdn.jp>
// 
//  Copyright (c) 2004-2014 smdn
// 
//  This program is free software; you can redistribute it and/or modify
//  it under the terms of the GNU General Public License as published by
//  the Free Software Foundation; either version 2 of the License, or
//  (at your option) any later version.
// 
//  This program is distributed in the hope that it will be useful,
//  but WITHOUT ANY WARRANTY; without even the implied warranty of
//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
//  GNU General Public License for more details.
//  
//  You should have received a copy of the GNU General Public License
//  along with this program; if not, write to the Free Software
//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

using System;
using System.Collections.Generic;
using System.Collections.ObjectModel;
using System.Globalization;
using System.IO;
using System.Linq;
using System.Resources;
using System.Text;
using System.Windows.Forms;

using Smdn.Formats.Thbgm;
using Smdn.IO;
using Smdn.Windows.Forms.ThbgmPlayer;

namespace Smdn.Applications.ThbgmExtractor {
  public static class ThbgmExtractor {
    private static StringBuilder log = new StringBuilder(1024 * 1024);

    public static StringBuilder Log {
      get { return log; }
    }

    private static TextWriter logWriter;

    internal static object LogLockObject {
      get { return logWriter; } // XXX
    }

    private static ResourceManager resourceManager = new ResourceManager("Smdn.Applications.ThbgmExtractor.Texts", typeof(ThbgmExtractor).Assembly);
    private static CultureInfo resourceCulture = null;

    public static System.Globalization.CultureInfo Culture {
      get { return resourceCulture; }
      set { resourceCulture = value; }
    }

    private static /*readonly*/ ReadOnlyCollection<ProductInfo> products;

    public static ReadOnlyCollection<ProductInfo> Products {
      get { return products; }
    }

    private static /*readonly*/ ReadOnlyCollection<EncoderConfig> encoderConfigs;

    public static ReadOnlyCollection<EncoderConfig> EncoderConfigs {
      get { return encoderConfigs; }
    }

    public static string VersionString {
      get { return string.Format("{0} {1}", Application.ProductName, Application.ProductVersion); }
    }

    private static string searchDirectory;

    [STAThread]
    public static void Main(string[] args)
    {
#if DEBUG
      resourceCulture = System.Globalization.CultureInfo.GetCultureInfo("en");
      Texts.Culture = resourceCulture;
      System.Threading.Thread.CurrentThread.CurrentUICulture = resourceCulture;
#endif

      logWriter = TextWriter.Synchronized(new StringWriter(log));

#if false && DEBUG
      Console.SetError(logWriter);

      Console.WriteLine("current directory: {0}", Environment.CurrentDirectory);
      Console.WriteLine("executable directory: {0}", Path.GetDirectoryName(Application.ExecutablePath));
#else
      Console.SetOut(logWriter);
      Console.SetError(logWriter);
#endif

      searchDirectory = Path.GetDirectoryName(Application.ExecutablePath);

      ReloadProductInfoes();

      ReloadEncoderConfig();

      Config.Load(searchDirectory);

      Application.EnableVisualStyles();
      Application.DoEvents();

      using (var dialog = new MainDialog()) {
        if (0 < args.Length) {
          if (PathUtils.AreExtensionEqual(args[0], ExtractionConfig.FileExtension)) {
            dialog.LoadExtractionConfig(args[0], true);
          }
          else {
            var product = ProductInfo.FindMatchedProduct(args[0], products);

            if (product != null) {
              var config = new ExtractionConfig();

              config.Product = product;
              config.BgmSourcePath = product.InstalledBgmSourcePath;
              config.EncoderConfig = EncoderConfig.Empty;
              config.Tracks = product.Tracks.Select(delegate(TrackInfo trackInfo) {
                return new Track(trackInfo);
              }).ToList().AsReadOnly();

              dialog.ExtractOnShown(config);
            }
          }
        }
        Application.Run(dialog);
      }

      Config.Save(products);
    }

    internal static void ReloadProductInfoes()
    {
      lock (ProductInfo.EmbeddedProducts) {
        var productsAndDates = new Dictionary<ProductInfo, DateTime>();

        foreach (var product in ProductInfo.EmbeddedProducts) {
          productsAndDates[product] = product.ReleaseDate;
        }

        foreach (var pair in LoadProductInfo(searchDirectory)) {
          var date = pair.Value.ReleaseDate;

          if (date == DateTime.MinValue)
            // use last write time instead of ProductInfo.ReleaseDate
            date = File.GetLastWriteTime(pair.Key);

          productsAndDates[pair.Value] = date;
        }

        // order by date of product info
        products = productsAndDates.OrderByDescending(pair => pair.Value).Select(pair => pair.Key).ToList().AsReadOnly();

        // load user environment info
        Config.Load(searchDirectory, products);
      }
    }

    private static Dictionary<string, ProductInfo> LoadProductInfo(string searchDirectory)
    {
      var ret = new Dictionary<string, ProductInfo>();

      try {
        foreach (var file in ProductInfo.SearchProductInfoFiles(searchDirectory, SearchOption.TopDirectoryOnly)) {
          try {
            var product = ProductInfo.LoadFrom(file);

            Console.WriteLine("loaded: {0} ({1})", file, product.Title);

            ret.Add(file, product);
          }
          catch (Exception ex) {
            Console.Error.WriteLine("file: {0}{1}{2}", file, Environment.NewLine, ex);
          }
        }
      }
      catch (Exception ex) {
        Console.Error.WriteLine(ex);
      }

      return ret;
    }

    internal static void ReloadEncoderConfig()
    {
      try {
        encoderConfigs = EncoderConfig.LoadFrom(Path.Combine(searchDirectory, EncoderConfig.ConfigFileName));
      }
      catch (Exception ex) {
        encoderConfigs = Array.AsReadOnly(new[] {EncoderConfig.Empty});
        Console.Error.WriteLine(ex);
      }
    }

    public static string GetText(string name, params object[] args)
    {
      return string.Format(resourceManager.GetString(name, resourceCulture) ?? string.Empty, args);
    }
  }
}
